@@ -28,6 +28,7 @@
 #include "ui_mcqr_param_all_quanti_dialog.h"
 #include "mcqrparamallquantidialog.h"
 #include <odsstream/odsdocwriter.h>
+#include <odsstream/odsexception.h>
 #include "../mainwindow.h"
 #include "../../output/ods/mcqrmetadatasheet.h"
 #include "../../input/metadataodshandler.h"
@@ -178,26 +179,43 @@ McqrParamAllQuantiDialog::doSaveFullRDataFile()
 void
 McqrParamAllQuantiDialog::doDownloadMetadataTemplate()
 {
+  std::vector<MsRunSp> list_of_msrun;
+  if(msp_mcqMsrunAlignementGroup.get() == nullptr)
+    {
+      list_of_msrun = msp_project.get()->getMsRunStore().getMsRunList();
+    }
+  else
+    {
+      list_of_msrun =
+        msp_mcqMsrunAlignementGroup.get()->getMsRunsInAlignmentGroup();
+    }
   QSettings settings;
   QString metadata_template_path = QFileDialog::getSaveFileName(
     this,
     tr("Save the template"),
     settings.value("mcqr/metadata_path", "untitled.ods").toString(),
     tr("Spreadsheet (*.ods)"));
-  if(metadata_template_path != NULL)
+  if(!metadata_template_path.isEmpty())
     {
       try
         {
-          CalcWriterInterface *p_writer = nullptr;
-          p_writer = new OdsDocWriter(metadata_template_path);
+          qDebug() << metadata_template_path;
+          CalcWriterInterface *p_writer =
+            new OdsDocWriter(metadata_template_path);
+          qDebug();
           McqrLoadDataMode method_select = getMcqrLoadDataMode();
-          McqrMetadataSheet(
-            p_writer,
-            msp_mcqMsrunAlignementGroup.get()->getMsRunsInAlignmentGroup(),
-            method_select);
+          qDebug();
+          McqrMetadataSheet(p_writer, list_of_msrun, method_select);
 
+          qDebug();
           p_writer->close();
           settings.setValue("mcqr/metadata_path", metadata_template_path);
+          qDebug();
+        }
+      catch(OdsException &error)
+        {
+          qDebug() << tr("error while writing metadata template:%1")
+                        .arg(error.qwhat());
         }
       catch(pappso::PappsoException &error)
         {
@@ -439,5 +457,5 @@ McqrParamAllQuantiDialog::getMcqrLoadDataMode()
 const QFileInfo &
 McqrParamAllQuantiDialog::getMetadataOdsFileInfo() const
 {
-    return m_metadataOdsFile;
+  return m_metadataOdsFile;
 }
