@@ -182,7 +182,8 @@ McqrRunView::handleMcqrMessages()
   QString mcqr_message = mp_rProcess->readAllStandardError();
   mcqr_message         = mcqr_message.trimmed();
   qDebug() << mcqr_message;
-  QStringList mcqr_messages = mcqr_message.split(QChar::LineSeparator);
+  QStringList mcqr_messages = mcqr_message.split(QRegExp(
+    QString("(\n|%1|%2)").arg(QChar::LineSeparator).arg(QChar::LineFeed)));
   for(QString message : mcqr_messages)
     {
       message = message.trimmed();
@@ -273,7 +274,7 @@ McqrRunView::saveRunRscript()
   if(qFile.open(QIODevice::WriteOnly))
     {
       QTextStream out(&qFile);
-      out << *(mp_rProcess->getRScriptRun().string());
+      out << mp_rProcess->getRscriptCode();
       qFile.close();
     }
 }
